"""
Twisted PythonCard PbEchoClient
"""

from PythonCard import model
from twisted.cred.credentials import UsernamePassword
from twisted.spread import pb
from twisted.internet import reactor
from twistedpythoncard import TwistedPythonCardApp

from pbecho import DefinedError

class TpcPbEchoPanel(model.Background):
    """
    TPC PB Echo GUI Panel
    """
    def __init__(self, *args):
        model.Background.__init__(self, *args)
        self.pbfactory = pb.PBClientFactory()

    def on_buttonLogin_mouseClick(self, event):
        reactor.connectTCP("localhost", pb.portno, self.pbfactory)
        self.pbfactory.login(
            UsernamePassword("guest", "guest")
                ).addCallbacks(self.loginsuccess,
                               self.loginfailure)

    def loginsuccess(self, perspective):
        self.components.StatusStaticText.visible = 1
        self.perspective = perspective

    def loginfailure(self, error):
        self.displaycontent("Couldn't login: "+error)

    def on_buttonSend_mouseClick(self, event):
        self.perspective.callRemote('echo',
            self.components.SendTextField.text
            ).addCallbacks(self.echosuccess,
                           self.echofailure)

    def echosuccess(self, message):
        self.displaycontent(message)

    def echofailure(self, error):
        t = error.trap(DefinedError)
        self.displaycontent("error received"+t)

    def displaycontent(self, text):
        self.components.ReceivedTextArea.text += text+'\n'

    def on_menuFileExit_select(self, event):
        self.Close(True)
        reactor.stop()


if __name__ == '__main__':
    app = TwistedPythonCardApp(TpcPbEchoPanel)
    app.MainLoop()

